.. _utils:


Utils
*****

.. currentmodule:: torchkge.utils

Dissimilarities
---------------
.. automodule:: torchkge.utils.dissimilarities
    :members:

Losses
------
.. automodule:: torchkge.utils.losses
    :members:

Operations
----------
.. automodule:: torchkge.utils.operations
    :members:
